==> haskell-coinbase-pro-0.9.3.2-282-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-CoOi5Hhspmo2u9xbDZnRIw
key:                  coinbase-pro-0.9.3.2-CoOi5Hhspmo2u9xbDZnRIw
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  a7d4d57e0955542c554850f4d00cc145
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-CoOi5Hhspmo2u9xbDZnRIw
depends:
    HsOpenSSL-0.11.7.9-CvmgaFAoNByycUo19HsuD
    aeson-2.1.2.1-LS8mizUYnpf1U9zpV4sjcf
    aeson-casing-0.2.0.0-G7FzKPXqHmbGJfgq75FPbK
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9aiao6Baet5LbFVZqeOgvR exceptions-0.10.5
    http-api-data-0.5.1-7OKDVIHydm2A3RZjZEW5Yf
    http-client-0.7.18-LXBlgncwp3M12RggVCuJyY
    http-client-tls-0.3.6.4-EpkYNSTVr5IILDsEq9OqBv
    http-streams-0.8.9.9-FLKbKYP7MguINUJRvWnHjT
    http-types-0.12.4-3waRWhsRr1C4PfAAAPJbwc
    io-streams-1.5.2.2-FoDLj2z59ut7YhsxB0uZJp
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    servant-0.20.2-4Sr4PTSppzZFbsCDmJdDqd
    servant-client-0.20-2PXYmIiQGaY4crM4QaX2oZ
    servant-client-core-0.20.2-8sHL0Qz92tcKjF8QuA8ZUm
    tasty-1.4.3-HK16IWl2qZuAE1kQP7GLN3
    tasty-hunit-0.10.1-4olJEdoQaAQ1sPVsKcqoD text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unagi-streams-0.2.7-7HqgMR9WTl9SCx0GtSWss
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i
    uuid-1.3.16-DTXFgrb7MThGeAanhZvVIB
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8
    websockets-0.12.7.3-JS7l6MER7dwKspn1yzLGaQ
    wuss-2.0.1.2-7oypfmDPV0NGLLqSfuWYfC

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-coinbase-pro-0.9.3.2-297-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-JSk2B5GtJpy4WyDGqq7KMe
key:                  coinbase-pro-0.9.3.2-JSk2B5GtJpy4WyDGqq7KMe
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  317a8abe59f74ae8ad6d1ba172432d8a
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-JSk2B5GtJpy4WyDGqq7KMe
depends:
    HsOpenSSL-0.11.7.9-CvmgaFAoNByycUo19HsuD
    aeson-2.1.2.1-H9spCVKCz3aBZuysSTfrjv
    aeson-casing-0.2.0.0-3wiwCu44PuVBq35Ozzrj7W
    async-2.2.5-7zRWRGcsDHK4x7TGVl8w2c base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9aiao6Baet5LbFVZqeOgvR exceptions-0.10.5
    http-api-data-0.5.1-CZpMF0NpgKA2Pio9pIzdsD
    http-client-0.7.18-163W4AHWMZxiWwErxEeuv
    http-client-tls-0.3.6.4-2oeYpKUjUcFHV14IdzgHEG
    http-streams-0.8.9.9-Adgwvsu89s7LdQYO8INlE2
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    io-streams-1.5.2.2-FoDLj2z59ut7YhsxB0uZJp
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-6CSLlS2XYBeLlFfm0MgCfu
    servant-0.20.2-FFa1gXnQbYRAyK6aXmtCn2
    servant-client-0.20-ChyNtWN7vFZ4YncFmlhFo
    servant-client-core-0.20.2-6ZWhDdJVLITHJtLrLqeLXw
    tasty-1.4.3-HK16IWl2qZuAE1kQP7GLN3
    tasty-hunit-0.10.1-4olJEdoQaAQ1sPVsKcqoD text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unagi-streams-0.2.7-7HqgMR9WTl9SCx0GtSWss
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    uuid-1.3.16-DTXFgrb7MThGeAanhZvVIB
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8
    websockets-0.12.7.3-JS7l6MER7dwKspn1yzLGaQ
    wuss-2.0.1.2-2ibx986nJJd2s02TcA6NZe

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
